:orphan:

Charge sensing
===============

Options: QPC or quantum dot

References
----------

* `Tuning a sensing dot`
* Jules van Oven, Msc thesis


Tips for tuning
---------------

* Is the bias current turned off?
* Have you depleted the 2deg enough?
* Optimize the peak by changing the detuning and the barrier to the reservoir
* If there interference from multiple RF signals?
* Try selecting a different peak of the SD
* Try recalibration of the RF frequency

